@@ -235,6 +235,9 @@ class AirflowTaskExecutor(TaskExecutor):
             is_paused_upon_creation=True,
             concurrency=self.airflow_config.dbnd_dag_concurrency,
         )
+        if hasattr(dag, "_description"):
+            dag._description = "Dynamic DAG generated by DBND"
+
         with dag:
             airflow_ops = {}
             for task_run in task_runs:
